@@ -1,14 +1,16 @@
-/* return human readable name for neb type */
 char * nebtype2str(__attribute__((__unused__)) int i) {
     return strdup("UNKNOWN");
 }
 
-/* return human readable name for nebcallback */
 char * nebcallback2str(__attribute__((__unused__)) int i) {
     return strdup("UNKNOWN");
 }
 
-/* return human readable name for eventtype */
 char * eventtype2str(__attribute__((__unused__)) int i) {
     return strdup("UNKNOWN");
 }
+
+void nm_log(__attribute__((__unused__)) int, __attribute__((__unused__))const char *, ...);
+void nm_log(__attribute__((__unused__)) int lvl, __attribute__((__unused__))const char * data, ...) {
+    return;
+}
