@@ -162,7 +162,7 @@ void clean_exit(int sig) {
 }
 
 /* print version */
-void print_version() {
+void print_version(void) {
     printf("gearman_top: version %s\n", GM_VERSION );
     printf("\n");
     exit( EXIT_SUCCESS );
@@ -170,7 +170,7 @@ void print_version() {
 
 
 /* print usage */
-void print_usage() {
+void print_usage(void) {
     printf("usage:\n");
     printf("\n");
     printf("gearman_top   [ -H <hostname>[:port]               ]\n");
@@ -215,6 +215,10 @@ void print_stats(char * hostnam) {
     if(port_c != NULL)
         port = atoi(port_c);
 
+    if(strlen(server) == 0) {
+        server = "localhost";
+    }
+
     /* get stats */
     stats = (mod_gm_server_status_t*)gm_malloc(sizeof(mod_gm_server_status_t));
     stats->function_num = 0;
